import { useRef, useState, useEffect } from 'react';
import { connect, history } from '@umijs/max';
import type { ActionType, ProFormInstance } from '@ant-design/pro-components';
import {
    ProTable, TableDropdown, PageContainer
} from '@ant-design/pro-components';
import { Button, Image, ConfigProvider, Select, message } from 'antd';
import { GetCompanyRecruiters, GetCompanyInfo, updateCompany, PostCompanyExport , PostCompanyTurnJobseeker} from '@/apis/api';
import { Imageprefix } from '@/constants';

const PagesMainCompanyListTable: React.FC = ({ dispatch, openModel, getId }: any) => {
    const actionRef = useRef<ActionType>();
    const [list, setList] = useState<object[]>([])
    const [total, setTotal] = useState<number>(0)
    const [page, setPage] = useState<number>(1)
    const [pageSize, setPageSize] = useState<number>(10)

    const setId = (id: number) => {
        getId(id)
    }

    useEffect(() => {
        if (!openModel.openModal) {
            actionRef.current.reload();
        }
    }, [openModel.openModal])

    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                        colorLink: '#4FBE70',
                    }
                }}
            >
                    <ProTable
                        size='small'
                        bordered={true}
                        scroll={{ x: 1300 }}
                        actionRef={actionRef}
                        dataSource={list}
                        columns={[
                            {
                                title: '账号',
                                dataIndex: 'username'
                            }, {
                                title: '手机号',
                                dataIndex: 'mobile'
                            }, {
                                title: '绑定时间',
                                dataIndex: 'updated_at',
                            },
                            {
                                title: '操作',
                                width: 300,
                                key: 'option',
                                valueType: 'option',
                                fixed: 'right',
                                render: (_, record, action) => [
                                    <Button key='1' type='link' onClick={() => {
                                        PostCompanyTurnJobseeker({company_id:record.company_id, customer_id: record.id, role: 1}).then(res => {
                                            message.success('解除授权成功');
                                            actionRef.current.reload();
                                        })
                                    }}>解除授权</Button>
                                    
                                ],
                            },
                        ]}
                        rowKey="id"
                        pagination={{
                            current: page,
                            pageSize: pageSize,
                            showSizeChanger: true,
                            total: total,
                            pageSizeOptions: [9, 18, 27, 99],
                            onChange(page, pageSize) {
                                setPage(page)
                                setPageSize(pageSize)
                            },
                            onShowSizeChange(current, size) {
                                setPage(current)
                                setPageSize(size)
                            }
                        }}
                        request={async (params = {} as Record<string, any>) =>
                            GetCompanyRecruiters({
                                page: page,
                                pagesize: pageSize,
                                sort: 'id',
                                sortby: 'desc',
                            }).then(res => {
                                setList(res.data.customers)
                                setTotal(res.data.total)
                            })
                        }
                        headerTitle="管理已经授权的账号"
                    />
            </ConfigProvider>
        </>
    );
};


export default connect(({ openModel }: any) => ({
    openModel
}))(PagesMainCompanyListTable);